@@ -354,10 +354,7 @@ fn parse(text: &str, allow_substvar: bool) -> Parse {
             self.tokens.last().map(|(kind, _)| *kind)
         }
         fn skip_ws(&mut self) {
-            while self.current() == Some(WHITESPACE)
-                || self.current() == Some(COMMENT)
-                || self.current() == Some(NEWLINE)
-            {
+            while self.current() == Some(WHITESPACE) || self.current() == Some(NEWLINE) {
                 self.bump()
             }
         }
@@ -367,7 +364,7 @@ fn parse(text: &str, allow_substvar: bool) -> Parse {
             while i > 0 {
                 i -= 1;
                 match self.tokens[i].0 {
-                    WHITESPACE | COMMENT | NEWLINE => {}
+                    WHITESPACE | NEWLINE => {}
                     _ => return Some(self.tokens[i].0),
                 }
             }
@@ -798,7 +795,7 @@ impl Entry {
         let tail_pos = new_root.children_with_tokens().count() - new_tail_len;
         new_root.splice_children(
             tail_pos - new_tail_len..tail_pos,
-            old_tail.into_iter().rev().collect(),
+            old_tail.into_iter().rev(),
         );
         let index = old_root.index();
         self.0
@@ -904,7 +901,7 @@ impl Entry {
             .skip(1)
             .any(|n| n.kind() == ENTRY);
         while let Some(n) = self.0.next_sibling_or_token() {
-            if n.kind() == WHITESPACE || n.kind() == COMMENT || n.kind() == NEWLINE {
+            if n.kind() == WHITESPACE || n.kind() == NEWLINE {
                 n.detach();
             } else if n.kind() == COMMA {
                 n.detach();
@@ -1502,7 +1499,7 @@ impl Relation {
             // First item in the list. Remove whitespace up to the pipe, the pipe and anything
             // before the next relation
             while let Some(n) = self.0.next_sibling_or_token() {
-                if n.kind() == WHITESPACE || n.kind() == COMMENT || n.kind() == NEWLINE {
+                if n.kind() == WHITESPACE || n.kind() == NEWLINE {
                     n.detach();
                 } else if n.kind() == PIPE {
                     n.detach();
